#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_CUMSUM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_CUMSUM_HPP_INCLUDED

#include <boost/simd/swar/include/functions/scalar/cumsum.hpp>

#endif
